@@ -26,6 +26,7 @@
 #' @param showDesign if TRUE, show design matrix instead of data 
 #' @param include vector of field names always to be included even when select or unique specified
 #' @param uselink default FALSE; if TRUE uses link values in evaluating uniqueness
+#' @param merge default FALSE but if TRUE, the ddl for the parameter is merged (cbind) to the estimates
 #' @export
 #' @return A data frame (\code{real}) is returned if \code{vcv=FALSE};
 #' otherwise, a list is returned also containing vcv.real: \item{real}{ data
@@ -39,15 +40,15 @@
 #' dipper.ddl=make.design.data(dipper.proc)
 #' mod.Phisex.pdot=crm(dipper.proc,dipper.ddl,
 #'  model.parameters=list(Phi=list(formula=~sex+time),p=list(formula=~1)),hessian=TRUE)
-#' xx=compute.real(mod.Phisex.pdot,"Phi",unique=TRUE,vcv=TRUE)
+#' xx=compute_real(mod.Phisex.pdot,"Phi",unique=TRUE,vcv=TRUE)
 #' @keywords utility
-compute.real <-function(model,parameter,ddl=NULL,dml=NULL,unique=TRUE,vcv=FALSE,se=FALSE,chat=1,subset=NULL,select=NULL,showDesign=FALSE,include=NULL,uselink=FALSE)
+compute_real <-function(model,parameter,ddl=NULL,dml=NULL,unique=TRUE,vcv=FALSE,se=FALSE,chat=1,subset=NULL,select=NULL,showDesign=FALSE,include=NULL,uselink=FALSE,merge=FALSE)
 {
 #  Note that the vector indices has 3 different meanings in the code as the code progresses.
 # if ddl not specified return results stored in model
   if(is.null(ddl))return(model$results$reals)
 # set mcmc value
-  mcmc=ifelse(class(model)[2]=="mcmc",TRUE,FALSE)
+  mcmc=ifelse(is(model,"mcmc"),TRUE,FALSE)
 # Setup data (ddl for a parameter) and extract dm; currently is either passed as an argument or stored in model
   data=ddl[[parameter]]
   if(!is.null(dml))
@@ -119,20 +120,51 @@ compute.real <-function(model,parameter,ddl=NULL,dml=NULL,unique=TRUE,vcv=FALSE,
   }
   varnames=unique(varnames)
   if(any(!select%in%names(df))) 
-	  warning(paste("These variable names not in data for real estimates: ",paste(varnames[!select%in%names(df)],collapse=""),sep=""))
+	  warning(paste("For parameter ",parameter," these variable names not in data for real estimates: ",paste(varnames[!select%in%names(df)],collapse=","),sep=""))
   varnames=varnames[varnames%in%names(df)]
   df=df[,varnames,drop=FALSE]
-# Check to make sure dimensions of beta and design matrix match
+# Check to make sure dimensions and names for beta and design matrix match
   results=model$results
   beta=results$beta[[parameter]]
   if(mcmc)
   {
-	  if(ncol(design)!=ncol(model$results$beta.mcmc[[parameter]]))
-   	     stop("Mismatch between number of design columns and length of beta")
+    used=names(model$results$beta.mcmc[[parameter]])%in%colnames(design)
+    if(ncol(design)!=ncol(model$results$beta.mcmc[[parameter]]))
+	  {
+	    warning(paste("Mismatch between number of design columns and length of beta for parameter ",parameter,
+	                  " Make sure ddl contains all needed data values. Not using following beta values: ",
+                    paste(names(model$results$beta.mcmc[[parameter]])[!used],collapse=",")))
+    } 
+    if(any(!used))
+    {
+      warning(paste("Mismatch between design column names and names for beta for parameter ",parameter,
+                    " Make sure ddl structure is correct. Not using following beta values: ",
+                    paste(names(model$results$beta.mcmc[[parameter]])[!used],collapse=",")))
+    }  
   } else
   {
-	  if(ncol(design)!=length(beta))
-         stop("Mismatch between number of design columns and length of beta")
+    used=names(beta)%in%colnames(design)
+    if(ncol(design)!=length(beta))
+	  {
+	    warning(paste("Mismatch between number of design columns and length of beta for parameter ",parameter,
+	                  " Make sure ddl contains all needed data values. Not using following beta values: ",
+	                  paste(names(beta)[!used],collapse=",")))
+    }
+    if(any(!used))
+    {
+      warning(paste("Mismatch between design column names and names for beta for parameter ",parameter,
+                    " Make sure ddl structure is correct. Not using following beta values: ",
+                    paste(names(beta)[!used],collapse=",")))
+    }
+                    
+  }
+  
+  if(any(!used))
+  {
+    newdesign=matrix(0,ncol=length(used),nrow=nrow(design))
+    colnames(newdesign)=colnames(design)
+    newdesign[,used]=design[,used]
+    design=newdesign
   }
 # Compute real parameters using function convert.link.to.real
 # added code to handle all parameters being fixed
@@ -143,8 +175,11 @@ compute.real <-function(model,parameter,ddl=NULL,dml=NULL,unique=TRUE,vcv=FALSE,
 	  if(mcmc)
 		  real=convert.link.to.real(t(design%*%t(results$beta.mcmc[[parameter]])),links=link,fixed=fixedvalues)
 	  else
-		  real=convert.link.to.real(design%*%beta,links=link,fixed=fixedvalues)
-     # Set fixed real parameters to their fixed values
+	    if(ncol(design)>0)
+	      real=convert.link.to.real(design%*%beta,links=link,fixed=fixedvalues)
+	    else
+	      real=rep(NA,nrow(design))
+	    # Set fixed real parameters to their fixed values
      real[fixedparms]=fixedvalues[fixedparms]
   }
 # Summarize reals for mcmc models or create dataframe with estimate=real for non-mcmc models
@@ -285,13 +320,20 @@ compute.real <-function(model,parameter,ddl=NULL,dml=NULL,unique=TRUE,vcv=FALSE,
 	  linkse[is.na(linkse)]=0
 	  linkse[is.infinite(linkse)]=0
 	  link.se[ind]=linkse
-	  link.values=design%*%beta
-	  link.values[ind]=suppressWarnings(log(real[ind]/(1-real[ind])))
-	  link.values[ind][abs(real[ind]-1)<1e-7]=100
-	  link.values[ind][abs(real[ind]-0)<1e-7]=-100
-	  links[ind]="logit"
-	  real.lcl=convert.link.to.real(link.values-1.96*link.se,links=links)
-	  real.ucl=convert.link.to.real(link.values+1.96*link.se,links=links)
+	  if(ncol(design)>0)
+	  {
+	    link.values=design%*%beta
+	    link.values[ind]=suppressWarnings(log(real[ind]/(1-real[ind])))
+	    link.values[ind][abs(real[ind]-1)<1e-7]=100
+	    link.values[ind][abs(real[ind]-0)<1e-7]=-100
+	    links[ind]="logit"
+	    real.lcl=convert.link.to.real(link.values-1.96*link.se,links=links)
+	    real.ucl=convert.link.to.real(link.values+1.96*link.se,links=links)
+	  } else
+	  {
+	    real.lcl=reals$estimate
+	    real.ucl=reals$estimate
+	  }
 #     Set v-c values of fixed parameters to 0
 	  vcv.real[fixedparms,]=0
 	  vcv.real[,fixedparms]=0
@@ -303,6 +345,7 @@ compute.real <-function(model,parameter,ddl=NULL,dml=NULL,unique=TRUE,vcv=FALSE,
     }   
 #  Setup subset or get unique records 
 	#reals=reals[do.call(order, reals),]
+  if(merge)reals=cbind(data,reals)
 	rownames(reals)=NULL
 	if(vcv)
 		return(list(real=reals,vcv=vcv.real))
