@@ -169,24 +169,22 @@ full.design.data=vector("list",length=length(parameters))
 	  } 
 	  if(!is.null(parameters[[i]]$tostrata) && parameters[[i]]$tostrata)
 	  {
+	    if(parameters[[i]]$whichlevel==0)
+	      field="stratum"
+	    else
+	      if(parameters[[i]]$whichlevel==1)
+	        field="state"  
+  	    else
+	        field=names(data$strata.list)[oth.index]
 		  if(is.null(parameters[[i]]$subtract.stratum)) 
 		  {
 			  if(parameters[[i]]$whichlevel==0)
-			  {
-				  field="stratum"
 			  	  parameters[[i]]$subtract.stratum=data$strata.labels
-			  }
 			  else
 			      if(parameters[[i]]$whichlevel==1)
-				  {
-					  field="state"  
-					  parameters[[i]]$subtract.stratum=data$strata.list$states
-				  }
-				  else
-				  {
-					  field=names(data$strata.list)[oth.index]
+   					  parameters[[i]]$subtract.stratum=data$strata.list$states
+  				  else
 					  parameters[[i]]$subtract.stratum=data$strata.list[[oth.index]]
-				  }
 		  }	  	  
 		  if(toupper(parameters[[i]]$subtract.stratum)[1]!="NONE")
 		  {
@@ -226,6 +224,16 @@ full.design.data=vector("list",length=length(parameters))
    full.design.data$ehmat=data$ehmat
    if(data$model=="MVMSCJS")
 	   full.design.data=initiate_pi(data,full.design.data)
+   if(data$model=="MSLD")
+   {
+     if(is.null(full.design.data$p$fix))full.design.data$p$fix=NA
+     full.design.data$p$fix[full.design.data$p$occ==max(full.design.data$p$occ)]=0
+     full.design.data$Psi$fix[full.design.data$Psi$occ==max(full.design.data$Psi$occ)&
+                              full.design.data$Psi$stratum!=full.design.data$Psi$tostratum]=0
+   }
+   # reset rownames
+   for(i in 1:length(parameters))
+     rownames(full.design.data[[i]])=NULL
    return(full.design.data)
 }
 #' Setup fixed values for pi in design data
